@@ -28,9 +28,11 @@
 #include "util.h"
 #include "parser.h"
 
-#include <QtCore/QIODevice>
+#include <QIODevice>
 
-#include <QtCore/QDebug>
+#include <QDebug>
+
+#include <algorithm>
 
 using namespace Massif;
 
@@ -52,8 +54,8 @@ ParserPrivate::ParserPrivate(Parser* parser, QIODevice* file, FileData* data,
     , m_nextLine(FileDesc)
     , m_currentLine(0)
     , m_error(NoError)
-    , m_snapshot(0)
-    , m_parentItem(0)
+    , m_snapshot(nullptr)
+    , m_parentItem(nullptr)
     , m_hadCustomAllocators(false)
     , m_expectedSnapshots(100)
 {
@@ -279,14 +281,14 @@ void ParserPrivate::parseHeapTreeLeaf(const QByteArray& line)
     // - merge "in XYZ places all below threshold"
     if (m_hadCustomAllocators) {
         Q_ASSERT(m_snapshot->heapTree());
-        QVector<TreeLeafItem*> newChildren = m_snapshot->heapTree()->children();
-        TreeLeafItem* belowThreshold = 0;
+        QList<TreeLeafItem*> newChildren = m_snapshot->heapTree()->children();
+        TreeLeafItem* belowThreshold = nullptr;
         uint places = 0;
         QString oldPlaces;
-        ///TODO: is massif translateable?
+        ///TODO: is massif translatable?
         QRegExp matchBT(QStringLiteral("in ([0-9]+) places, all below massif's threshold"),
                                             Qt::CaseSensitive, QRegExp::RegExp2);
-        QVector<TreeLeafItem*>::iterator it = newChildren.begin();
+        QList<TreeLeafItem*>::iterator it = newChildren.begin();
         while(it != newChildren.end()) {
             TreeLeafItem* child = *it;
             if (matchBT.indexIn(QString::fromLatin1(child->label())) != -1) {
@@ -310,10 +312,10 @@ void ParserPrivate::parseHeapTreeLeaf(const QByteArray& line)
             label.replace(oldPlaces.toUtf8(), QByteArray::number(places));
             belowThreshold->setLabel(label);
         }
-        qSort(newChildren.begin(), newChildren.end(), sortLeafsByCost);
+        std::sort(newChildren.begin(), newChildren.end(), sortLeafsByCost);
         m_snapshot->heapTree()->setChildren(newChildren);
     }
-    m_parentItem = 0;
+    m_parentItem = nullptr;
 }
 
 struct SaveAndRestoreItem
@@ -388,7 +390,7 @@ bool ParserPrivate::parseheapTreeLeafInternal(const QByteArray& line, int depth)
         }
     }
 
-    TreeLeafItem* newParent = 0;
+    TreeLeafItem* newParent = nullptr;
     if (!isCustomAlloc) {
         TreeLeafItem* leaf = new TreeLeafItem;
         leaf->setCost(cost);
